lilypondparsertools.SyntaxNode
==============================

.. abjad-lineage:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode

.. autoclass:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.SyntaxNode.SyntaxNode.SyntaxNode.__str__
   :noindex:
